DynamicPolynomialFS

Struct DynamicPolynomialFS 

pub struct DynamicPolynomialFS<R: FixedSemiring> {
    pub coeffs: Vec<R>,
}
Polynomials of dynamic degree. The implementation is tailored to work with FixedSemirings. To be used in UAIR and PIOP where ZIP+ degree bound is not observed anymore.

Note that operations involving dynamic polynomials do not trim leading zeros meaning one can end up with unequal objects of the type DynamicPoly<R> that represent equal polynomials, therefore trim has to be called before checking equality.

Fields

coeffs: Vec<R>

Implementations

Source

impl<R: FixedSemiring> DynamicPolynomialFS<R>

pub fn new_trimmed(coeffs: impl AsRef<[R]>) -> Self

Create a new polynomial with the given coefficients.

pub fn new(coeffs: impl AsRef<[R]>) -> Self

pub fn degree(&self) -> Option<usize>

pub fn trim(&mut self)